==> haskell-hls-refactor-plugin-2.1.0.0-59-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-refactor-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-refactor-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-refactor-plugin-2.1.0.0-1mgIyR2L99XJYvvY3SkUi6
key:                  hls-refactor-plugin-2.1.0.0-1mgIyR2L99XJYvvY3SkUi6
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           zubin.duggal@gmail.com
author:               The Haskell IDE Team
synopsis:             Exactprint refactorings for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  4c3be0f0021d5a517589292d308ac06d
exposed:              True
exposed-modules:
    Development.IDE.GHC.Compat.ExactPrint Development.IDE.GHC.Dump
    Development.IDE.GHC.ExactPrint Development.IDE.Plugin.CodeAction
    Development.IDE.Plugin.CodeAction.Util

hidden-modules:
    Development.IDE.Plugin.CodeAction.Args
    Development.IDE.Plugin.CodeAction.ExactPrint
    Development.IDE.Plugin.CodeAction.PositionIndexed
    Development.IDE.Plugin.Plugins.AddArgument
    Development.IDE.Plugin.Plugins.Diagnostic
    Development.IDE.Plugin.Plugins.FillHole
    Development.IDE.Plugin.Plugins.FillTypeWildcard
    Development.IDE.Plugin.Plugins.ImportUtils

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-refactor-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-refactor-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-refactor-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-refactor-plugin
hs-libraries:         HShls-refactor-plugin-2.1.0.0-1mgIyR2L99XJYvvY3SkUi6
depends:
    aeson-2.1.2.1-6FuMYI3vdPa8Ts5NPsnpCg base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.2-7bG7braRZax6ZJaJ3dSesR deepseq-1.4.8.0
    dlist-1.0-E99MqJW5mmB4kr4PCgIESI
    extra-1.7.16-KxrHBQWVwMp2M62XitBte8 ghc-9.4.8 ghc-boot-9.4.8
    ghc-exactprint-1.6.1-7axuNmUvC9rLDVsc4zeWrL
    ghcide-2.1.0.0-7mveeBu1NdO3tDaPLTwSr0
    hls-graph-2.1.0.0-E0uwKa062XbErlHzLpQDMc
    hls-plugin-api-2.1.0.0-2mMBQBjk997A47exxFPkZd
    lens-5.3.1-57CGCDOUfQCLkJSlnZcVUR
    lsp-2.1.0.0-GxokUjVxBLy4j05JlhgdFg mtl-2.2.2
    parser-combinators-1.3.0-11YwG5dPNej79xqbn9HKav
    regex-applicative-0.3.4-BwAgx4l3uL4BgpFT8PLwyW
    regex-tdfa-1.3.2.4-9ZyuPp8BFYO5HpZyySDZc8
    retrie-1.2.3-1y6GbD5JAzcAnLlEmWsfCh
    syb-0.7.3-Lap6GPARkRXCVbqA2faY6P text-2.0.2
    text-rope-0.3-B63XxTtZ9rH6f5aGYdHxkH time-1.12.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-89DcpQLd7HI30AdGz5XyJk

haddock-interfaces:
    /usr/share/doc/haskell-hls-refactor-plugin/html/hls-refactor-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-refactor-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-refactor-plugin-2.1.0.0-94-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-refactor-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-refactor-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-refactor-plugin-2.1.0.0-ExDUElgsYmt9j5A89B9r6p
key:                  hls-refactor-plugin-2.1.0.0-ExDUElgsYmt9j5A89B9r6p
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           zubin.duggal@gmail.com
author:               The Haskell IDE Team
synopsis:             Exactprint refactorings for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  3a316291e06ee6d9afce919d014a45a8
exposed:              True
exposed-modules:
    Development.IDE.GHC.Compat.ExactPrint Development.IDE.GHC.Dump
    Development.IDE.GHC.ExactPrint Development.IDE.Plugin.CodeAction
    Development.IDE.Plugin.CodeAction.Util

hidden-modules:
    Development.IDE.Plugin.CodeAction.Args
    Development.IDE.Plugin.CodeAction.ExactPrint
    Development.IDE.Plugin.CodeAction.PositionIndexed
    Development.IDE.Plugin.Plugins.AddArgument
    Development.IDE.Plugin.Plugins.Diagnostic
    Development.IDE.Plugin.Plugins.FillHole
    Development.IDE.Plugin.Plugins.FillTypeWildcard
    Development.IDE.Plugin.Plugins.ImportUtils

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-refactor-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-refactor-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-refactor-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-refactor-plugin
hs-libraries:         HShls-refactor-plugin-2.1.0.0-ExDUElgsYmt9j5A89B9r6p
depends:
    aeson-2.1.2.1-3HLieqpkeG06w6MDAYdLLk base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.3-1SaGr9SWFYZ17MG1fTAOKi deepseq-1.4.8.0
    dlist-1.0-DlYyWPxbaG7vpSilKIFCh extra-1.7.16-CyTEZvSfBxsKCwY9ZtJE7E
    ghc-9.4.8 ghc-boot-9.4.8
    ghc-exactprint-1.6.1-I9AXRGbygyx7CNm2jZnyfK
    ghcide-2.1.0.0-EGobQkKgR8zaeADYgxOC5
    hls-graph-2.1.0.0-7LnpvrkjhrNH9iznMLZXCG
    hls-plugin-api-2.1.0.0-EfBvd6pBF3is65S9wzuFu
    lens-5.3.3-1zYcQilqoBK5EhYwkXjOnb
    lsp-2.1.0.0-4wEItkatDyfAFCzTPH6SAN mtl-2.2.2
    parser-combinators-1.3.0-11YwG5dPNej79xqbn9HKav
    regex-applicative-0.3.4-2GK1Gu1joVisoYduu8AjJ
    regex-tdfa-1.3.2.5-71D7aDzS2d23Ft8PQEnlRo
    retrie-1.2.3-4xmNpLWUS55A2ToWNKattd
    syb-0.7.3-C5AaeelSWDKGvBUWTjIxkt text-2.0.2
    text-rope-0.3-31JrMTK7qlyJ4XXJrO6vBR time-1.12.2
    transformers-0.5.6.2
    unordered-containers-0.2.20.1-JRJBW0Nl9iEJULI134IWXM

haddock-interfaces:
    /usr/share/doc/haskell-hls-refactor-plugin/html/hls-refactor-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-refactor-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
